<?php

namespace Sukellos\Admin;

use Sukellos\WP_Sukellos_Admin_Builder_Basic_Loader;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\WP_PLoad;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\Utils\WP_Helper;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 * Main admin is used as controller to init admin menu and all other admin pages
 *
 * @since 1.0.0
 */
class WP_Sukellos_Admin_Builder_Basic_Admin extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();


        // Add action to delegate settings fields creation to Sukellos Fw Licenses admin
        // Use priority to order Licenses
        add_action( 'sukellos_fw/admin/create_licenses_fields', array( $this, 'action_create_licenses_fields' ), 9, 1 );

        WP_Log::info( 'WP_Sukellos_Admin_Builder_Basic_Admin->init OK!',[], WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_text_domain());
    }


    /**
     * Gets the plugin configuration URL
     * This is used to build actions list in plugins page
     * Leave blank ('') to disable
     *
     * @since 1.0.0
     *
     * @return string plugin settings URL
     */
    public function get_settings_url() {

        return admin_url( 'admin.php?page='.WP_PLoad::WP_SK_OPTIONS_SUFFIX_PARAM.'_admin_builder' );
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */


    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}


    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items() {

        // To improve code readability
        $plugin_name = WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_name();
        $options_suffix_param = WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_options_suffix_param();
        $text_domain = WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_text_domain();
        $plugin_dir_url = WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_plugin_dir_url();

        // Admin page.
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => WP_Helper::sk__( 'Admin Builder Pro' ),
                'title' => WP_Helper::sk__( 'Admin Builder Pro' ),
                'id' => WP_PLoad::WP_SK_OPTIONS_SUFFIX_PARAM.'_admin_builder',
                'capability' => 'manage_options',
                'parent_id' => WP_PLoad::WP_SK_OPTIONS_SUFFIX_PARAM.'_dashboard',
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 12,
                'desc' => 'Easily build a powerful and beautiful custom admin panel',
                'use_reset' => true,
                'save' => WP_Helper::sk__( 'Save' ), // Text for save button
                'reset' => WP_Helper::sk__( 'Reset' ), // Text for reset button
                'reset_question' => WP_Helper::sk__( 'Do you really want to reset form?' ), // Question asked to confirm reset
                'use_tabs' => false,
            )
        );


        // Build HTML content
        ob_start();
        ?>
        <div class="sk-content-panel">
            <div class="sk-content-panel-content">
                <div class="sk-content-panel-2columns-container">
                    <div class="sk-content-panel-column">
                        <div class="sk-content-panel-2columns-container header">
                            <div class="sk-content-panel-icon dashicons dashicons-palmtree"></div>
                            <div class="sk-content-panel-column-content">
                                <h3>Easy Admin Pages. Magnify Options</h3>
                            </div>
                        </div>
                        <div class="sk-content-panel-column-content body">
                            <p>The Admin Builder is one of the main features embedded in Sukellos Framework. It allows to <b>easily build powerful and beautiful custom admin pages</b> in WordPress Dashboard. The Admin Builder can be included very simply in your own plugin to create an administration page in a few lines of code. This takes the hassle out of your hands, making high-level designs possible with very little development skill. No need to worry about implementing the form, handling writing fields, just focus on your configuration logic.</p>
                            <p>Admin Builder is a powerful way to create configuration pages to <b>manage WordPress options</b>. Creating an AJAX request becomes child’s play. All types of standard fields are present, and even more: text, textarea, WYSIWYG, color picker, date picker, checkbox, enable, select and multiple choices on custom or WordPress data (users, posts, terms…), upload, number slider, notice, content… Admin pages can be displayed with or without tabs.</p>
                        </div>
                    </div>
                    <div class="sk-content-panel-column">
                        <div class="sk-content-panel-2columns-container header">
                            <div class="sk-content-panel-icon dashicons dashicons-editor-expand"></div>
                            <div class="sk-content-panel-column-content">
                                <h3>Enrich Post Types And User Profiles</h3>
                            </div>
                        </div>
                        <div class="sk-content-panel-column-content body">
                            <p>Take control of custom fields in any type of posts. <b>The creation of Metabox becomes very simple.</b> All the standard fields can also be used, but this time by associating them with any post type, stored as post_meta. Admin Builder allows to disable classical custom fields display.</p>
                            <p><b>Users can be enriched</b> by adding fields that are directly visible and modifiable in their own profiles. The management of these user_meta is also possible directly in administration pages.</p>
                            <p>In the same way as for the options, the management of the post_meta and the user_meta is simplified as much as possible. <b>Just a few lines of code are enough.</b></p>
                        </div>
                    </div>
                    <div class="sk-content-panel-column">
                        <div class="sk-content-panel-2columns-container header">
                            <div class="sk-content-panel-icon dashicons dashicons-saved"></div>
                            <div class="sk-content-panel-column-content">
                                <h3>Automatic CSS Generation. SCSS Support.</h3>
                            </div>
                        </div>
                        <div class="sk-content-panel-column-content body">
                            <p>In the administration pages, <b>the options can be taken automatically into account in CSS.</b> Each field value can be dynamically associated with a CSS. More complex styles can also be generated from an administration page thanks to the <b>magic method create_css</b>, in a very simple way.</p>
                            <p>Admin Builder allows the use of a code-like configuration field, thanks to the inclusion of the Ace project. This control offers an input area that supports the CSS / SCSS format. This field can be <b>automatically generated and included in the WordPress front end.</b></p>
                        </div>
                    </div>
                    <div class="sk-content-panel-column">
                        <div class="sk-content-panel-2columns-container header">
                            <div class="sk-content-panel-icon dashicons dashicons-welcome-learn-more"></div>
                            <div class="sk-content-panel-column-content">
                                <h3>Fully Documented And Supported. Lot Of Examples.</h3>
                            </div>
                        </div>
                        <div class="sk-content-panel-column-content body">
                            <p><b>Admin Builder comes not only with lots of usage examples, but also with a basic plugin template.</b> This saves you a tremendous amount of time by relying on well-written, reusable, and tested code.</p>
                            <p>Admin Builder is designed to be used by developers. <b>Many hooks are available</b> to allow full style and behavior customization.</p>
                            <p>A particular effort is made on this site to offer you the most complete and precise documentation. Our support is also at your disposal in case of difficulty.</p>
                        </div>
                    </div>
                </div>
                <div class="sk-content-panel-1column-container discover">
                        <div class="sk-content-panel-column-content">
                            <a class="button" target="_blank" href="https://sukellos.com/wordpress-sukellos-fw-admin-builder/">Discover Admin Builder Pro</a>
                        </div>
                </div>
            </div>
        </div>

        <?php

        $content = ob_get_contents();
        ob_end_clean();

        // Create a content
        $admin_page->create_content(
            array(
                'id' => $options_suffix_param.'_content_1',
                'name' => __('Mon content', $text_domain),
                'desc' => '',
                'content' => $content,
            )
        );
    }


    /**
     * Tools fields creation
     */
    public function action_create_licenses_fields( $admin_page ) {

        // Create a header
        $admin_page->create_header(
            array(
                //'type' => Item_Type::HEADER,
                // Common
                'id' => WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_options_suffix_param().'_header_admin_builder_basic_license',
                'name' => 'Admin Builder Basic License',
                'desc' => WP_Helper::sk__( 'This is where you enter your license key to activate the Admin Builder Basic plugin.' ),
            )
        );

        // Create an select option field
        $admin_page->create_option(
            array(
                'type' => Item_Type::EDD_LICENSING,
                // Common
                'id' => WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_options_suffix_param().'_admin_builder_license_basic',
                'name' => WP_Helper::sk__( 'License key' ),
                'desc' => WP_Helper::sk__( 'Please enter your license key for Admin Builder Basic' ),
                'default' => '',
                'hidden' => false,
                'example' => '',
                // Specific
                'validity_id' => '',
                'store_url' => 'https://wp-adminbuilder.com',
                'download_id' => '1891',
                'download_name' => 'Sukellos Fw & Admin Builder Basic',
                'plugin_file' => WP_Sukellos_Admin_Builder_Basic_Loader::instance()->get_plugin_file(),
                'wp_override' => true,
                'activate' => WP_Helper::sk__( 'Activate' ),
                'deactivate' => WP_Helper::sk__( 'Deactivate' ),
                'sukellos_rule_exception' => true,
            )
        );
    }
}