<?php

namespace Sukellos\WPFw\AdminBuilder\Fields;

use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\AdminBuilder\Item_Type;

defined( 'ABSPATH' ) or exit;

/**
 * Date field
 *
 * @since 1.0
 * @type date
 */
class Date_Field extends Field {

    /**
     * Default settings specific for this field
     * @var array
     */
    private $default_specific_field_settings = array(

        'type' => Item_Type::DATE,

        'date' => true,
        'time' => false,
    );

    private static $date_epoch;

    /**
     * Constructor
     *
     * @param $settings
     */
    public function __construct( $settings, $handler ) {

        parent::__construct( $settings, $handler );

        if ( empty( self::$date_epoch ) ) {
            self::$date_epoch = date( 'Y-m-d', 0 );
        }
    }

    /**
     * Get the default field settings
     * @return array
     */
    protected function get_default_specific_field_settings() {

        return $this->default_specific_field_settings;
    }

	/**
	 * Display for options and meta
     * @param bool $echo Whether to display or return string, default true
     */
    public function render_specific_body( $echo=true ) {

        $date_format = 'Y-m-d H:i';
        $placeholder = 'YYYY-MM-DD HH:MM';
        if ( $this->get_date() && ! $this->get_time() ) {

            $date_format = 'Y-m-d';
            $placeholder = 'YYYY-MM-DD';
        } else if ( ! $this->get_date() && $this->get_time() ) {

            $date_format = 'H:i';
            $placeholder = 'HH:MM';
        }

        // Get value
        $value = $this->get_value();

        $html_content = sprintf('<input class="input-date%s%s" name="%s" placeholder="%s" id="%s" type="text" value="%s" />',
            ( $this->get_date() ? ' date' : '' ),
            ( $this->get_time() ? ' time' : '' ),
            $this->get_id(),
            $placeholder,
            $this->get_id(),
            esc_attr( ($value > 0) ? date( $date_format, $value ) : '' )
        );

        if ( $echo ) {

            echo $html_content;
        } else {

            return $html_content;
        }
	}


    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /**
     * Filter : sukellos_fw/admin_builder/field/set_cleaned_value_{field_id}
     * Used to clean up a value before updating it in field
     *
     * @param $value the raw value
     */
    public function filter_field_set_cleaned_value( $value ) {

        WP_Log::debug('Date_Field->filter_field_set_cleaned_value - Before', ['value' => $value]);
        if ( $value == '' ) {
            return 0;
        }
        if ( ! $this->get_date() && $this->get_time() ) {
            $value = self::$date_epoch . ' ' . $value;
        }
        WP_Log::debug('Date_Field->filter_field_set_cleaned_value - After', ['value' => $value]);
        $timestamp_value = strtotime( $value );
        return $timestamp_value;
    }

    /**
     * Enqueue the scripts
     *
     * @since 1.0.0
     *
     * @return void
     */
    public function enqueue_scripts() {

        wp_enqueue_style( 'sk-admin-builder-date-field-style', plugins_url( '../../css/sk-field-date.css', __FILE__ ) );

        wp_enqueue_script( 'jquery-ui-core' );
        wp_enqueue_script( 'jquery-ui-slider' );
        wp_enqueue_script( 'jquery-ui-datepicker' );
        wp_enqueue_script( 'sk-admin-builder-jquery-ui-timepicker-addon', plugins_url( '../../js/min/jquery-ui-timepicker-addon-min.js', __FILE__ ), array( 'jquery-ui-datepicker', 'jquery-ui-slider' ) );
    }


    /**
     * Load the javascript
     *
     * @since 1.0.0
     *
     * @return void
     */
    public function init_scripts() {
        ?>
        <script>
            jQuery(document).ready(function($) {
                "use strict";

                var datepickerSettings = {
                    dateFormat: 'yy-mm-dd',

                    beforeShow: function(input, inst) {
                        $('#ui-datepicker-div').addClass('sk-admin-builder-date-datepicker');

                        // Fix the button styles
                        setTimeout( function() {
                            jQuery('#ui-datepicker-div')
                                .find('[type=button]').addClass('button').end()
                                .find('.ui-datepicker-close[type=button]').addClass('button-primary');
                        }, 0);
                    },

                    // Fix the button styles
                    onChangeMonthYear: function() {
                        setTimeout( function() {
                            jQuery('#ui-datepicker-div')
                                .find('[type=button]').addClass('button').end()
                                .find('.ui-datepicker-close[type=button]').addClass('button-primary');
                        }, 0);
                    }
                };
                $('.sk-admin-builder-date input[type=text]').each(function() {
                    var $this = $(this);
                    if ( $this.hasClass('date') && ! $this.hasClass('time') ) {
                        $this.datepicker( datepickerSettings );
                    } else if ( ! $this.hasClass('date') && $this.hasClass('time') ) {
                        $this.timepicker( datepickerSettings );
                    } else {
                        $this.datetimepicker( datepickerSettings );
                    }
                });
            });
        </script>
        <?php
    }
}
